@@ -1,3 +1,3 @@
 class TestMyISAM < ActiveRecord::Base
-  set_table_name 'test_myisam'
+  self.table_name = 'test_myisam'
 end
