@@ -37,6 +37,12 @@ def should_support_postgresql_import_functionality
         assert !topic.changed?
       end
 
+      if ENV['AR_VERSION'].to_f > 4.1
+        it "moves the dirty changes to previous_changes" do
+          assert topic.previous_changes.present?
+        end
+      end
+
       it "marks models as persisted" do
         assert !topic.new_record?
         assert topic.persisted?
@@ -110,6 +116,26 @@ def should_support_postgresql_import_functionality
         assert_equal [%w(King It)], result.results
       end
 
+      context "when given an empty array" do
+        let(:result) { Book.import([], returning: %w(title)) }
+
+        setup { result }
+
+        it "returns empty arrays for ids and results" do
+          assert_equal [], result.ids
+          assert_equal [], result.results
+        end
+      end
+
+      context "when a returning column is a serialized attribute" do
+        let(:vendor) { Vendor.new(hours: { monday: '8-5' }) }
+        let(:result) { Vendor.import([vendor], returning: %w(hours)) }
+
+        it "creates records" do
+          assert_difference("Vendor.count", +1) { result }
+        end
+      end
+
       context "when primary key and returning overlap" do
         let(:result) { Book.import(books, returning: %w(id title)) }
 
@@ -228,6 +254,30 @@ def should_support_postgresql_import_functionality
         assert_equal({}, Vendor.first.json_data)
       end
     end
+
+    %w(json jsonb).each do |json_type|
+      describe "with pure #{json_type} fields" do
+        let(:data) { { a: :b } }
+        let(:json_field_name) { "pure_#{json_type}_data" }
+        it "imports the values from saved records" do
+          vendor = Vendor.create!(name: 'Vendor 1', json_field_name => data)
+
+          Vendor.import [vendor], on_duplicate_key_update: [json_field_name]
+          assert_equal(data.as_json, vendor.reload[json_field_name])
+        end
+      end
+    end
+  end
+
+  describe "with enum field" do
+    let(:vendor_type) { "retailer" }
+    it "imports the correct values for enum fields" do
+      vendor = Vendor.new(name: 'Vendor 1', vendor_type: vendor_type)
+      assert_difference "Vendor.count", +1 do
+        Vendor.import [vendor]
+      end
+      assert_equal(vendor_type, Vendor.first.vendor_type)
+    end
   end
 
   describe "with binary field" do
