@@ -138,6 +138,15 @@ def should_support_recursive_import
       books.each do |book|
         assert_equal book.topic_id, second_new_topic.id
       end
+
+      books.each { |book| book.topic_id = nil }
+      assert_no_difference "Book.count", books.size do
+        Book.import books, validate: false, on_duplicate_key_update: [:topic_id]
+      end
+
+      books.each do |book|
+        assert_equal book.topic_id, nil
+      end
     end
 
     unless ENV["SKIP_COMPOSITE_PK"]
@@ -183,5 +192,34 @@ def should_support_recursive_import
         end
       end
     end
+
+    # If returning option is provided, it is only applied to top level models so that SQL with invalid
+    # columns, keys, etc isn't generated for child associations when doing recursive import
+    describe "returning" do
+      let(:new_topics) { Build(1, :topic_with_book) }
+
+      it "imports objects with associations" do
+        assert_difference "Topic.count", +1 do
+          Topic.import new_topics, recursive: true, returning: [:content], validate: false
+          new_topics.each do |topic|
+            assert_not_nil topic.id
+          end
+        end
+      end
+    end
+
+    # If no returning option is provided, it is ignored
+    describe "no returning" do
+      let(:new_topics) { Build(1, :topic_with_book) }
+
+      it "is ignored and imports objects with associations" do
+        assert_difference "Topic.count", +1 do
+          Topic.import new_topics, recursive: true, no_returning: true, validate: false
+          new_topics.each do |topic|
+            assert_not_nil topic.id
+          end
+        end
+      end
+    end
   end
 end
